/*
      This file is part of GNUnet
      (C) 

      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
      by the Free Software Foundation; either version 2, or (at your
      option) any later version.

      GNUnet is distributed in the hope that it will be useful, but
      WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
      General Public License for more details.

      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
      Free Software Foundation, Inc., 59 Temple Place - Suite 330,
      Boston, MA 02111-1307, USA.
 */

/**
 * @file include/gnunet_spider_service.h
 * @brief API to the distributed HTTP spider service
 * @author Christian Grothoff
 */
#ifndef GNUNET_SPIDER_SERVICE_H
#define GNUNET_SPIDER_SERVICE_H

#ifdef __cplusplus
extern "C"
{
#if 0                           /* keep Emacsens' auto-indent happy */
}
#endif
#endif

/**
 * Version of the spider API.
 */
#define GNUNET_SPIDER_VERSION 0x00000000


/**
 * Opaque handle.
 */
struct GNUNET_SpiderHandle;


/**
 * Connect to spider service.
 *
 * @param cfg configuration to use 
 * @param uh url handler to call
 * @param uh_cls closure for uh
 * @return NULL on error
 */
struct GNUNET_SpiderHandle *
GNUNET_SPIDER_connect (struct GNUNET_CONFIGURATION_Handle *cfg);


/**
 * Add the given starting URL to the set for spidering.
 *
 * @param h service handle
 * @param url URL to add
 */
void
GNUNET_SPIDER_add (struct GNUNET_SpiderHandle *h,
		   const char *url);


/**
 * Disconnect from the service
 * 
 * @param h service handle
 */
void
GNUNET_SPIDER_disconnect (struct GNUNET_SpiderHandle *h);


#if 0                           /* keep Emacsens' auto-indent happy */
{
#endif
#ifdef __cplusplus
}
#endif

#endif
